/*
 * Java
 *
 * Copyright 2018-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.profiling.profiler;

import java.util.logging.Logger;

import com.microej.profiling.internal.Strings;

import ej.bon.Immortals;

/**
 * Profile the immortalls memory usage.
 */
public class ImmortalsProfiler extends MemoryProfiler {

	/**
	 * Prints the used immortal memory.
	 *
	 * @param printTotal
	 *            <code>true</code> if the total memory should be printed.
	 */
	public static void printUsedMemory(boolean printTotal) {
		printMemory(getLogger(), Immortals.totalMemory(), Immortals.freeMemory(), true, printTotal);
	}

	/**
	 * Prints the free immortal memory.
	 *
	 * @param printTotal
	 *            <code>true</code> if the total memory should be printed.
	 */
	public static void printFreeMemory(boolean printTotal) {
		printMemory(getLogger(), Immortals.totalMemory(), Immortals.freeMemory(), false, printTotal);
	}

	private static Logger getLogger() {
		return Logger.getLogger(ImmortalsProfiler.class.getSimpleName());
	}

	@Override
	public long getCurrentValue() {
		return Immortals.freeMemory();
	}

	@Override
	protected long getTotal() {
		return Immortals.totalMemory();
	}

	@Override
	protected String getType() {
		return Strings.IMMORTAL;
	}
}
