/*
 * Java
 *
 * Copyright 2018-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.profiling.profiler;

import java.util.Map;
import java.util.Set;
import java.util.logging.Logger;

import com.microej.profiling.internal.Strings;

/**
 *
 * Profile the active threads count.
 *
 */
public class ThreadsProfiler implements ComparableProfiler, InstantProfiler {

	private static final String PREFIX = Strings.ACTIVE_THREADS;

	/**
	 * Prints the stack traces to the logger.
	 *
	 * @see #vmDump()
	 */
	public static void printStackTraces() {
		Logger.getLogger(ThreadsProfiler.class.getSimpleName()).info(vmDump());
	}

	/**
	 * Dumps the running thread's stacks.
	 *
	 * @return a {@link String} containing the vm dump.
	 */
	public static String vmDump() {
		StringBuffer dump = new StringBuffer(Strings.VM_DUMP + Strings.LINE_BREAK);
		Map<Thread, StackTraceElement[]> allStackTraces = Thread.getAllStackTraces();
		Set<Thread> keys = allStackTraces.keySet();
		dump.append(keys.size() + Strings.ACTIVE_THREADS + Strings.LINE_BREAK);
		for (Thread thread : keys) {
			dump.append(Strings.DRAW_LINE + Strings.LINE_BREAK);
			dump.append(Strings.JAVA_THREAD + thread.getId() + Strings.CLOSE_RECT_BRACKET + Strings.LINE_BREAK);
			dump.append(Strings.NAME + thread.getName() + Strings.PRIO + thread.getPriority() + Strings.STATE
					+ thread.getState() + Strings.LINE_BREAK + Strings.LINE_BREAK);
			dump.append(thread.getClass().getName() + Strings.COLLON + Strings.LINE_BREAK);
			StackTraceElement[] stackTraceElements = allStackTraces.get(thread);
			for (StackTraceElement stackTraceElement : stackTraceElements) {
				dump.append(Strings.TAB + Strings.AT + stackTraceElement.getClassName() + Strings.DOT
						+ stackTraceElement.getMethodName() + Strings.OPEN_BRACKET + stackTraceElement.getFileName()
						+ Strings.COLLON + stackTraceElement.getLineNumber() + Strings.CLOSE_BRACKET
						+ Strings.LINE_BREAK);
			}
		}
		dump.append(Strings.DRAW_LINE_2);
		return dump.toString();
	}

	@Override
	public long getCurrentValue() {
		return Thread.activeCount();
	}

	@Override
	public String printValue(long value) {
		return Long.toString(value);
	}

	@Override
	public String getName() {
		return PREFIX;
	}

	@Override
	public long compare(long start, long end) {
		return end - start;
	}

	@Override
	public boolean isBiggerPrinted(long v1, long v2) {
		return v1 > v2;
	}
}
