/*
 * Java
 *
 * Copyright 2015-2017 IS2T. All rights reserved.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.microej.wadapps.management.util;

import java.util.ArrayList;
import java.util.Collection;

import ej.components.dependencyinjection.ServiceLoaderFactory;
import ej.observable.Observable;
import ej.wadapps.admin.Application;
import ej.wadapps.admin.Application.State;
import ej.wadapps.admin.ApplicationLifecycleListener;
import ej.wadapps.admin.ApplicationsManager;
import ej.wadapps.app.BackgroundService;
import ej.wadapps.management.BackgroundServicesList;

/**
 * Default {@link BackgroundServicesList} implementation.
 */
public class BackgroundServicesListImpl extends Observable
		implements BackgroundServicesList, ApplicationLifecycleListener {

	private final Collection<BackgroundService> backgrounds;

	/**
	 * Default constructor.
	 */
	public BackgroundServicesListImpl() {
		this.backgrounds = new ArrayList<>();
		ServiceLoaderFactory.getServiceLoader().getService(ApplicationsManager.class)
				.addApplicationLifecycleListener(this);
	}

	@Override
	public void add(BackgroundService background) {
		synchronized (this.backgrounds) {
			this.backgrounds.add(background);
		}
		setChanged();
		notifyObservers();
	}

	@Override
	public void remove(BackgroundService background) {
		synchronized (this.backgrounds) {
			this.backgrounds.remove(background);
		}
		setChanged();
		notifyObservers();
	}

	@Override
	public BackgroundService[] getBackgroundServices() {
		synchronized (this.backgrounds) {
			return this.backgrounds.toArray(new BackgroundService[this.backgrounds.size()]);
		}
	}

	@Override
	public void stateChanged(Application application) {
		if (application.getState() == State.INSTALLED) {
			boolean cleaned;
			synchronized (this.backgrounds) {
				cleaned = ArrayUtils.cleanup(this.backgrounds);
			}
			if (cleaned) {
				setChanged();
				notifyObservers();
			}
		}
	}
}
