/*
 * Java
 *
 * Copyright 2021 MicroEJ Corp. All rights reserved.
 * MicroEJ Corp. PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.microej.wadapps.property;

import ej.components.dependencyinjection.ServiceLoaderFactory;
import ej.util.property.PropertyLoader;
import ej.wadapps.admin.Application;
import ej.wadapps.admin.ApplicationsManager;

/**
 * Property loader that searches in the current Wadapps application property.
 *
 * @see ApplicationsManager#getCurrentApplication()
 * @see Application#getProperty(String)
 */
public class WadappsPropertyLoader implements PropertyLoader {

	@Override
	public String getProperty(String key) {
		return getProperty(key, null);
	}

	@Override
	public String getProperty(String key, String defaultValue) {
		String returnedValue = defaultValue;
		ApplicationsManager applicationsManager = ServiceLoaderFactory.getServiceLoader()
				.getService(ApplicationsManager.class);
		if (applicationsManager != null) {
			Application application = applicationsManager.getCurrentApplication();
			if (application != null) {
				String value = application.getProperty(key);
				if (value != null) {
					returnedValue = value;
				}
			}
		}
		return returnedValue;
	}
}
