package com.microej.wadapps.rcommand;
/*
 * Java
 *
 * Copyright 2017-2021 MicroEJ Corp. All rights reserved.
 * MicroEJ Corp. PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

import ej.components.dependencyinjection.ServiceLoaderFactory;
import ej.rcommand.CommandReader;
import ej.rcommand.CommandSender;
import ej.wadapps.admin.Product;

/**
 *
 */
public class DeviceInfoCommand extends AbstractCommand {
	@Override
	protected String getManagedCommand() {
		return CommandConstants.DEVICE_INFO;
	}

	@Override
	protected void commandReceived(CommandReader commandReader, CommandSender commandSender) {
		Product product = ServiceLoaderFactory.getServiceLoader().getService(Product.class);
		IconInfoProvider iconInfoProvider = ServiceLoaderFactory.getServiceLoader().getService(IconInfoProvider.class);
		int hostVersion;
		try {
			hostVersion = commandReader.readInt();
		} catch (Throwable ex) {
			hostVersion = 0;
		}
		commandSender.startCommand(CommandConstants.DEVICE_INFO_SUCCESS);
		if (hostVersion >= 1) {
			commandSender.sendInt(CommandConstants.DEVICE_INFO_VERSION);
		}
		commandSender.sendString(product.getDeviceIdentifier());
		commandSender.sendString(product.getFirmwareIdentifier());
		commandSender.sendString(product.getFirmwareVersion());

		if (iconInfoProvider != null) {
			commandSender.sendBoolean(true);
			commandSender.sendInt(iconInfoProvider.getAcceptedIconWidth());
			commandSender.sendInt(iconInfoProvider.getAcceptedIconHeight());
		} else {
			commandSender.sendBoolean(false);
		}

		if (hostVersion >= 1) {
			commandSender.sendBoolean(Boolean.getBoolean("com.microej.wadapps.allowSignedCommands")); //$NON-NLS-1$
			commandSender.sendBoolean(Boolean.getBoolean("com.microej.wadapps.allowUnsignedCommands")); //$NON-NLS-1$
		}
		commandSender.flushCommand();
	}

}
