/*
 * Java
 *
 * Copyright 2016-2021 MicroEJ Corp. All rights reserved.
 * MicroEJ Corp. PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.microej.wadapps.rcommand;

import ej.components.dependencyinjection.ServiceLoaderFactory;
import ej.rcommand.CommandReader;
import ej.rcommand.CommandSender;
import ej.wadapps.admin.Application;
import ej.wadapps.admin.ApplicationsManager;
import ej.wadapps.app.Activity;
import ej.wadapps.management.ActivitiesList;

/**
 * A command allowing to list all the activities registered in the activity
 * list.
 */
public class ListActivitiesCommand extends AbstractCommand {

	@Override
	protected String getManagedCommand() {
		return CommandConstants.LIST_ACTIVITIES;
	}

	@Override
	protected void commandReceived(CommandReader commandReader, CommandSender commandSender) {
		ActivitiesList activitiesList = ServiceLoaderFactory.getServiceLoader().getService(ActivitiesList.class);
		ApplicationsManager admin = ServiceLoaderFactory.getServiceLoader().getService(ApplicationsManager.class);
		if (admin == null) {
			commandSender.startCommand(CommandConstants.LIST_ACTIVITIES_ERROR);
			commandSender.sendString("No application manager"); //$NON-NLS-1$
		} else {
			commandSender.startCommand(CommandConstants.LIST_ACTIVITIES_SUCCESS);
			if (activitiesList == null) {
				commandSender.sendInt(0);
			} else {
				Activity[] activities = activitiesList.getActivities();
				if (activities == null) {
					commandSender.sendInt(0);
				} else {
					commandSender.sendInt(activities.length);
					for (Activity a : activities) {
						String id = a.getID();
						commandSender.sendString(id != null ? id : "<null>"); //$NON-NLS-1$
						Application app = admin.getApplication(a);
						commandSender.sendString(app != null ? app.getIdentifier() : "<unknown>"); //$NON-NLS-1$
					}
				}
			}
		}
		commandSender.flushCommand();
	}

}
