/*
 * Java
 *
 * Copyright 2016-2021 MicroEJ Corp. All rights reserved.
 * MicroEJ Corp. PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.microej.wadapps.rcommand;

import ej.components.dependencyinjection.ServiceLoaderFactory;
import ej.rcommand.CommandReader;
import ej.rcommand.CommandSender;
import ej.wadapps.app.Activity;
import ej.wadapps.management.ActivitiesList;
import ej.wadapps.management.ActivitiesScheduler;

/**
 * A command allowing to ask the activity scheduler to show an activity.
 */
public class ShowActivityCommand extends AbstractCommand {

	@Override
	protected String getManagedCommand() {
		return CommandConstants.SHOW_ACTIVITY;
	}

	@Override
	protected void commandReceived(CommandReader commandReader, CommandSender commandSender) {
		try {
			String id = commandReader.readString();
			ActivitiesList activitiesList = ServiceLoaderFactory.getServiceLoader().getService(ActivitiesList.class);
			if (activitiesList != null) {
				Activity[] activities = activitiesList.getActivities();
				if (activities != null) {
					for (Activity activity : activities) {
						if (id.equals(activity.getID())) {
							ActivitiesScheduler activitiesScheduler = ServiceLoaderFactory.getServiceLoader()
									.getService(ActivitiesScheduler.class);
							if (activitiesScheduler != null) {
								activitiesScheduler.show(activity);
								commandSender.startCommand(CommandConstants.SHOW_ACTIVITY_SUCCESS);
							} else {
								commandSender.startCommand(CommandConstants.SHOW_ACTIVITY_ERROR);
								commandSender.sendString("No activity scheduler"); //$NON-NLS-1$
							}
							commandSender.flushCommand();
							return;
						}
					}
				}
			}
			throw new IllegalArgumentException("No such activity"); //$NON-NLS-1$
		} catch (Exception e) {
			commandSender.startCommand(CommandConstants.SHOW_ACTIVITY_ERROR);
			commandSender.sendString(e.getMessage());
			commandSender.flushCommand();
		}
	}

}
