/*
 * Java
 *
 * Copyright 2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.authz.acl;

/**
 * The interface to the database that lists all permissions.
 */
public interface AclDataAccess {

	/**
	 * Adds a new permission.
	 *
	 * @param user
	 *            the subject of this permission.
	 * @param action
	 *            the action authorized by this permission.
	 * @param resource
	 *            the target of this permission.
	 */
	void add(String user, String action, Object resource);

	/**
	 * Gets the {@link AclEntry} (the permissions) concerning a given pair of user and resource.
	 *
	 * @param user
	 *            the subject of this request.
	 * @param resource
	 *            the target of this request.
	 * @return the permissions concerning the given pair of {@code user} and {@code resource}.
	 */
	AclEntry getEntry(String user, Object resource);

}
