/*
 * Java
 *
 * Copyright 2014-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.basedriver;

import ej.ecom.Device;

/**
 * Listener on any events coming from the Controller.
 */
public interface ControllerListener {

	/**
	 * An error occurred on a device.
	 * 
	 * @param <D>
	 *            the type of the device to be registered
	 * @param deviceType
	 *            the type of the device to be registered
	 * @param device
	 *            the device itself
	 */
	<D extends Device> void onError(Class<D> deviceType, D device);

	/**
	 * An event occurred on a device.
	 * 
	 * @param <D>
	 *            the type of the device to be registered
	 * @param deviceType
	 *            the type of the device
	 * @param device
	 *            the device itself
	 */
	<D extends Device> void onEvent(Class<D> deviceType, D device);

	/**
	 * Registers a new device with the given type.
	 * 
	 * @param <D>
	 *            the type of the device to be registered
	 * @param deviceType
	 *            the type of the device to be registered
	 * @param device
	 *            the device to be registered
	 */
	<D extends Device> void onRegister(Class<D> deviceType, D device);

	/**
	 * Unregisters the given device.
	 * 
	 * @param <D>
	 *            the type of the device to be registered
	 * @param device
	 *            the device to be unregistered
	 */
	<D extends Device> void onUnregister(D device);
}
