/*
 * Java
 *
 * Copyright 2014-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.basedriver;

import java.io.IOException;

/**
 * Describe the capabilities of a thermostat.
 */
public interface Thermostat extends Profile {

	/**
	 * Gets the modes managed by the thermostat.
	 *
	 * @return an array of supported mode, null if unknown.
	 */
	ThermostatMode[] getSupportedModes();

	/**
	 * Sets the last known mode.
	 *
	 * @param mode
	 *            the mode to set.
	 * @throws IOException
	 *             if there is a communication error with the device
	 */
	void setMode(ThermostatMode mode) throws IOException;

	/**
	 * Gets the last known mode.
	 *
	 * @return the last known mode, null if not known.
	 */
	ThermostatMode getLastknownMode();

	/**
	 * Request an update of the currentMode.
	 *
	 * @throws IOException
	 *             if there is a communication error with the device
	 */
	void requestUpdate() throws IOException;
}
