/*
 * Java
 *
 * Copyright 2016-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.basedriver.event.impl;

import java.util.HashMap;
import java.util.Map;

import ej.basedriver.Thermostat;
import ej.basedriver.ThermostatMode;
import ej.basedriver.event.ThermostatEvent;

/**
 *
 */
public class DefaultThermostatEvent extends AbstractEvent<Thermostat> implements ThermostatEvent {

	private final ThermostatMode currentMode;
	private final Map<ThermostatMode, Double> values;

	/**
	 * @param device
	 */
	public DefaultThermostatEvent(Thermostat device) {
		super(device);
		this.currentMode = device.getLastknownMode();
		values = new HashMap<ThermostatMode, Double>();
		for (ThermostatMode mode : device.getSupportedModes()) {
			values.put(mode, mode.getLastKnownValue());
		}
	}

	/**
	 * Gets the mode.
	 *
	 * @return the currentMode.
	 */
	@Override
	public ThermostatMode getMode() {
		return currentMode;
	}


	@Override
	public double getValue(ThermostatMode mode) {
		return values.get(mode);
	}

}
