/*
 * Java
 *
 * Copyright 2014-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.basedriver.zwave;

import java.io.IOException;
import java.io.InputStream;

import ej.basedriver.zwave.frame.DataFrame;
import ej.basedriver.zwave.util.ZwaveLogger;

public class ZwaveReceiveThread extends Thread {
	private InputStream inputStream;
	private ZwaveSession session;
	private final ZwaveSendThread sendThread;
	private final ZwaveLogger logger;
	private boolean stopped = false;

	public ZwaveReceiveThread(ZwaveSendThread sendThread, ZwaveLogger logger) {
		setName(ZwaveReceiveThread.class.getSimpleName());
		this.sendThread = sendThread;
		this.logger = logger;
	}

	public void setZwaveSession (ZwaveSession session) {
		this.session = session;
	}

	/**
	 * @param inputStream
	 */
	public void setInputStream (InputStream inputStream) {
		this.inputStream = inputStream;
	}

	@Override
	public void run() {
		try {
			while(!stopped) {
				int read = inputStream.read();
				switch (read) {
				case ZwaveProtocol.SOF:
					DataFrame dataFrame = readFrame();
					logger.logReceiveFrame(dataFrame.getBytes());

					if (dataFrame.isValid()) {
						sendThread.sendAck();
						session.receiveValidFrame(dataFrame);
					} else {
						sendThread.sendNak();
					}
					break;
				case ZwaveProtocol.ACK:
					session.receiveAck();
					break;
				case ZwaveProtocol.NAK:
					session.receiveNak();
					break;
				case ZwaveProtocol.CAN:
					session.receiveCan();
					break;
				default:
					break;
				}
			}
		} catch (IOException e) {
		}

		try {
			inputStream.close();
		} catch (IOException e) {
		}

		ZwaveController controller = this.session.getController();
		if (controller.isStarted()) {
			this.session.getController().stop();
		}
	}

	private DataFrame readFrame() throws IOException {
		byte len = (byte) (inputStream.read() & BYTE_MASK);
		byte [] contents = new byte [len+2];
		contents[0] = ZwaveProtocol.SOF;
		contents[1] = len;

		for (int i = 2; i <= len ; i++) {
			contents[i] = (byte) (inputStream.read() & BYTE_MASK);
		}

		byte checksum = (byte) (inputStream.read() & BYTE_MASK);
		contents[contents.length-1] = checksum;
		return new DataFrame(contents);
	}

	/**
	 * 
	 */
	public void halt() {
		stopped = true;
		interrupt();
	}

	private static final int BYTE_MASK = 0xFF;
}
