/*
 * Java
 *
 * Copyright 2016-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.basedriver.zwave.util;

/**
 *
 */
public class NumberUtil {

	private NumberUtil() {

	}

	/**
	 * Gets the double value of a int.
	 *
	 * @param bytes
	 *            Array of byte.
	 * @param offset
	 *            Offset of the int.
	 * @param len
	 *            Length of the value.
	 * @param precision
	 *            Precision of the value.
	 * @return the double value.
	 */
	public static double readDouble(byte[] bytes, int offset, int len, int precision) {
		return readDouble(readInt(bytes, offset, len), precision);
	}

	/**
	 * Gets the double value of a int.
	 *
	 * @param value
	 *            The int value.
	 * @param precision
	 *            Precision of the value.
	 * @return the double value.
	 */
	public static double readDouble(int value, int precision) {
		double pow = 1;
		for (int i = 0; i < precision; i++) {
			pow *= 10;
		}
		return value / pow;
	}

	public static int readInt(byte[] bytes, int offset, int len) {
		int value = 0;
		int step = 0;
		while(step < len){
			value = value << 8;
			value += bytes[offset+step];
			step++;
		}
		return value;
	}

	public static byte[] writeInt(double value, int precision) {
		byte[] res = new byte[4];
		int intValue = (int) Math.floor(value);
		double rest = value - intValue;
		int pow = 1;
		for (int i = 0; i < precision; i++) {
			pow *= 10;
		}
		intValue = (int) (intValue * pow + Math.floor(rest * pow));
		//		ByteArray.writeInt(res, 0, intValue, ByteArray.BIG_ENDIAN);
		res[0] = (byte) (intValue >> 24);
		res[1] = (byte) (intValue >> 16);
		res[2] = (byte) (intValue >> 8);
		res[3] = (byte) (intValue /*>> 0*/);

		return res;
	}
}
