/*
 * Java
 *
 * Copyright 2018-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.bluetooth;

import ej.annotation.Nullable;

/**
 * The <code>BluetoothDescriptor</code> class represents a remote or a local GATT descriptor.
 * <p>
 * Remote descriptors may be retrieved by {@link BluetoothCharacteristic#getDescriptor(int) getting the descriptors} of
 * a remote characteristic.
 * <p>
 * Local descriptors may be retrieved by {@link BluetoothAdapter#addService adding a local service} to the adapter.
 * <p>
 * This class provides a method to get the characteristic to which the descriptor belongs.
 */
public class BluetoothDescriptor extends BluetoothAttribute {

	/**
	 * Private constructor.
	 */
	private BluetoothDescriptor() {
		throw new RuntimeException();
	}

	/**
	 * Returns the characteristic to which this descriptor belongs.
	 * <p>
	 * This method returns {@code null} if this is a local descriptor and it has not been added to a characteristic.
	 *
	 * @return the descriptor to which this descriptor belongs.
	 */
	public @Nullable BluetoothCharacteristic getCharacteristic() {
		throw new RuntimeException();
	}
}
