/*
 * Java
 *
 * Copyright 2008-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.fp.widget;

import ej.fp.Widget;

/**
 * This widget holds all methods required by MicroUI implementation to be compatible with the MicroUI LEDs engine.
 * <p>
 * A LED is a widget that represents a LED. Its intensity is variable.
 * <p>
 * Note the widget label must be an integer. It allows MicroUI implementation to retrieve a LED from an integer index.
 * The first LED index must be <code>0</code> and last LED index must be <code>availableNumberOfLEDs - 1</code>, where
 * <code>availableNumberOfLEDs</code> is retrieved using method
 * <code>Device.getDevice().getWidgets(MicroUILED.class).size()</code>.
 */
public abstract class MicroUILED extends Widget {

	/**
	 * Minimal value of intensity according MicroUI specification.
	 */
	public static final int MIN_INTENSITY = 0;

	/**
	 * Maximal value of intensity according MicroUI specification.
	 */
	public static final int MAX_INTENSITY = 255;

	private int id;

	/**
	 * Creates a widget LED compatible with MicroUI implementation.
	 */
	public MicroUILED() {
	}

	@Override
	public void finalizeConfiguration() {
		super.finalizeConfiguration();

		// throws an exception if label is not an integer
		this.id = Integer.parseInt(getLabel());
	}

	/**
	 * Gets the LED identifier (equals to its label).
	 *
	 * @return the LED identifier.
	 */
	public int getID() {
		return this.id;
	}

	/**
	 * Sets the intensity of this led.
	 *
	 * @param intensity
	 *            the intensity to set.
	 */
	public abstract void setIntensity(int intensity);

	/**
	 * Gets the intensity of this led.
	 *
	 * @return intensity the led intensity.
	 */
	public abstract int getIntensity();

}
