/*
 * Java
 *
 * Copyright 2016-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.style.background;

import ej.microui.display.GraphicsContext;
import ej.style.container.Rectangle;

/**
 * Represents the background of the elements.
 */
public interface Background {

	/**
	 * Tells whether or not the background is transparent. If this background is transparent, the parent of the element
	 * it applies to needs to be repainted simultaneously with its child.
	 *
	 * @return <code>true</code> if the background is transparent, <code>false</code> otherwise.
	 */
	boolean isTransparent();

	/**
	 * Applies the background on a graphics context.
	 *
	 * @param g
	 *            the graphics context.
	 * @param bounds
	 *            the available rectangle.
	 * @param color
	 *            the background color.
	 */
	void apply(GraphicsContext g, Rectangle bounds, int color);

}
