/*
 * Java
 *
 * Copyright 2016-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.style.border;

import ej.microui.display.GraphicsContext;
import ej.style.container.Rectangle;

/**
 * Represents the border of the elements.
 *
 * @see ej.style.Style#getBorder()
 * @see ej.style.outline.Outline
 */
public interface Border {

	/**
	 * Adds this border wrapping to a rectangle.
	 *
	 * @param rectangle
	 *            the rectangle to wrap.
	 */
	void wrap(Rectangle rectangle);

	/**
	 * Removes this border wrapping from a rectangle.
	 *
	 * @param rectangle
	 *            the rectangle to unwrap.
	 */
	void unwrap(Rectangle rectangle);

	/**
	 * Applies the border on a graphics context.
	 *
	 * @param g
	 *            the graphics context.
	 * @param bounds
	 *            the available rectangle.
	 * @param color
	 *            the border color.
	 */
	void apply(GraphicsContext g, Rectangle bounds, int color);

}
