/*
 * Java
 *
 * Copyright 2016-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.style.registry;

import java.util.Map;

import ej.annotation.Nullable;
import ej.style.Element;
import ej.util.map.WeakValueHashMap;

/**
 * The element registry matches elements with IDs (string).
 */
public class ElementRegistry {

	private static Map<String, Element> Elements = createElements();

	/**
	 * Kernel lazy initialization method for {@link ElementRegistry#Elements}.
	 *
	 * @return the new map.
	 */
	private static Map<String, Element> createElements() {
		return new WeakValueHashMap<>(0);
	}

	private ElementRegistry() {
	}

	/**
	 * Registers an element with its ID.
	 * <p>
	 * The given element is weakly referenced.
	 *
	 * @param id
	 *            the ID.
	 * @param element
	 *            the element.
	 */
	public static void registerElement(String id, Element element) {
		Elements.put(id.toLowerCase(), element);
	}

	/**
	 * Gets the element registered with an ID.
	 *
	 * @param id
	 *            the ID.
	 * @return the element for the given ID or <code>null</code> if none.
	 */
	@Nullable
	public static Element requestElement(String id) {
		return Elements.get(id.toLowerCase());
	}

}
