/*
 * Java
 *
 * Copyright 2016-2017 IS2T. All rights reserved.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package ej.util.filemanager;

/**
 *
 */
public class StorageID {

	/**
	 * @param id
	 *            the storage identifier to check.
	 * @throws IllegalArgumentException
	 *             if the given storage identifier is not a valid identifier.
	 */
	public static void check(String id) {
		if (id.length() == 0) {
			throw new IllegalArgumentException("Bad storage identifier: zero-length identifier.");
		}
		if (!isLetter(id.charAt(0))) {
			throw new IllegalArgumentException("Bad storage identifier: identifier does not start with a letter.");
		}

		for (int i = 1; i < id.length(); i++) {
			if (!isValidPart(id.charAt(i))) {
				throw new IllegalArgumentException("Bad storage identifier: '" + id.charAt(i) + "' is not a valid character.");
			}
		}
	}

	private static boolean isLetter(char c) {
		return Character.isLowerCase(c) || Character.isUpperCase(c) || '_' == c;
	}

	private static boolean isValidPart(char c) {
		return isLetter(c) || Character.isDigit(c) || '-' == c || '.' == c;
	}

}
