/*
 * Java
 *
 * Copyright 2015-2019 IS2T. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break IS2T warranties on the whole library.
 */
package ej.wadapps.application;

/**
 * The application manager gives information on the available applications.
 */
public interface ApplicationManager {

	/**
	 * Adds an application lifecycle listener.
	 * <p>
	 * It will be notified for each application event: start, stop.
	 *
	 * @param applicationLifecycleListener
	 *            the listener to add.
	 */
	void addApplicationLifecycleListener(ApplicationLifecycleListener applicationLifecycleListener);

	/**
	 * Removes an application lifecycle listener.
	 * <p>
	 * If the given listener is not registered, nothing is done.
	 *
	 * @param applicationLifecycleListener
	 *            the listener to remove.
	 */
	void removeApplicationLifecycleListener(ApplicationLifecycleListener applicationLifecycleListener);

	/**
	 * Gets all available applications.
	 * <p>
	 * If there is no application, this method returns an empty array.
	 *
	 * @return all available applications.
	 */
	Application[] getApplications();

}
