/*
 * Java
 *
 * Copyright 2015-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.wadapps.management;


import ej.observable.Observable;
import ej.observable.Observer;
import ej.wadapps.app.Activity;

/**
 * Holds a list of activities.
 */
public interface ActivitiesList {

	/**
	 * Adds an observer to this activities list.
	 * <p>
	 * The observer will be notified when the activities list will be modified.
	 * 
	 * @param observer
	 *            an observer to be added.
	 * @throws NullPointerException
	 *             if the given observer is <code>null</code>.
	 * @see Observable#addObserver(Observer)
	 * @see #add(Activity)
	 * @see #remove(Activity)
	 */
	void addObserver(Observer observer) throws NullPointerException;

	/**
	 * Deletes an observer to this activities list.
	 * <p>
	 * The observer will no longer be notified of this activities list modification.
	 * 
	 * @param observer
	 *            an observer to be removed.
	 * @see Observable#deleteObserver(Observer)
	 */
	void deleteObserver(Observer observer);

	/**
	 * Adds an activity.
	 * <p>
	 * The observers are notified with the activity as argument.
	 * 
	 * @param activity
	 *            the activity to be added.
	 */
	void add(Activity activity);

	/**
	 * Removes an activity.
	 * <p>
	 * The observers are notified with the activity as argument.
	 * 
	 * @param activity
	 *            the activity to be removed.
	 */
	void remove(Activity activity);

	/**
	 * Gets all registered activities.
	 * 
	 * @return all activities.
	 */
	Activity[] getActivities();

}
