/*
 * Java
 *
 * Copyright 2015-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 *
 */
package ej.wadapps.management;

import ej.observable.Observable;
import ej.observable.Observer;
import ej.wadapps.admin.Application;

/**
 * Provides the meta-data associated with an application.
 */
public interface ApplicationMetadataProvider {
	/**
	 * Adds an observer to this application meta-data provider.
	 * <p>
	 * The observer will be notified when the activities list will be modified.
	 * 
	 * @param observer
	 *            an observer to be added.
	 * @throws NullPointerException
	 *             if the given observer is <code>null</code>.
	 * @see Observable#addObserver(Observer)
	 * @see #setApplicationMetadata(Application, ApplicationMetadata)
	 */
	void addObserver(Observer observer) throws NullPointerException;

	/**
	 * Deletes an observer to this application meta-data provider.
	 * <p>
	 * The observer will no longer be notified of this activities list modification.
	 * 
	 * @param observer
	 *            an observer to be removed.
	 * @see Observable#deleteObserver(Observer)
	 */
	void deleteObserver(Observer observer);

	/**
	 * Returns the meta-data of the given application or {@code null} if the application has not meta-data.
	 * 
	 * @param application
	 *            application whose meta-data is requested.
	 * @return the meta-data of the given application or {@code null}.
	 */
	ApplicationMetadata getApplicationMetadata(Application application);

	/**
	 * Links an application and it meta-data.
	 * 
	 * @param application
	 *            the application to link.
	 * @param applicationMetadata
	 *            the meta-data of the application.
	 * @throws SecurityException
	 *             if a security manager exits and if the caller does not have the appropriate permissions.
	 */
	void setApplicationMetadata(Application application, ApplicationMetadata applicationMetadata)
			throws SecurityException;
}
