/*
 * Java
 *
 * Copyright 2018-2019 IS2T. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break IS2T warranties on the whole library.
 */
package ej.wadapps.monosandbox.service;

import ej.service.loader.CompositeServiceLoader;
import ej.service.loader.FilePropertiesServiceLoader;
import ej.service.loader.SystemPropertiesServiceLoader;
import ej.wadapps.application.Application;
import ej.wadapps.application.ApplicationManager;
import ej.wadapps.service.SharedServiceFactory;

/**
 * Defines the order of the service loading resolution:
 * <ol>
 * <li>the services defined by dependency injection locally in all apps.</li>
 * <li>the services shared in the instance of the shared registry.</li>
 * <li>the services defined by dependency injection globally in the system properties.</li>
 * </ol>
 */
public class ServiceLoaderMonoSandbox extends CompositeServiceLoader {

	private static final String PROPERTIES_PACKAGE = "/properties/"; //$NON-NLS-1$
	private static final String SERVICES_LIST = ".services"; //$NON-NLS-1$

	/**
	 * Creates the service loader.
	 */
	public ServiceLoaderMonoSandbox() {
		// Add the service loader for each app.
		SystemPropertiesServiceLoader systemPropertiesServiceLoader = new SystemPropertiesServiceLoader();
		ApplicationManager applicationManager = systemPropertiesServiceLoader.getService(ApplicationManager.class);
		if (applicationManager != null) {
			Application[] installedApplications = applicationManager.getApplications();
			for (Application application : installedApplications) {
				addServiceLoader(new FilePropertiesServiceLoader(
						PROPERTIES_PACKAGE + application.getIdentifier() + SERVICES_LIST));
			}
		}
		addServiceLoader(SharedServiceFactory.getSharedServiceRegistry());
		addServiceLoader(systemPropertiesServiceLoader);
	}
}
