/*
 * Java
 *
 * Copyright 2019-2020 IS2T. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break IS2T warranties on the whole library.
 */
package ej.wadapps.multisandbox.application;

import java.io.InputStream;

import org.eclipse.core.runtime.IProgressMonitor;

import ej.wadapps.application.Application;
import ej.wadapps.application.ApplicationOperationException;
import ej.wadapps.application.ApplicationPermission;

/**
 * The application installer allows to install and uninstall applications in a KF environment.
 * <ol>
 * <li>Install: the feature is installed by KF.</li>
 * <li>Uninstall: the feature is uninstalled by KF.</li>
 * </ol>
 */
public class ApplicationInstallerKF extends AbstractApplicationInstallerKF {

	/**
	 * Creates an application installer on KF.
	 *
	 * @param applicationManager
	 *            the applications manager it depends on.
	 */
	public ApplicationInstallerKF(ApplicationManagerKF applicationManager) {
		super(applicationManager);
	}

	@Override
	public Application install(InputStream stream, IProgressMonitor monitor) throws ApplicationOperationException {
		checkPermission(null, ApplicationPermission.INSTALL_ACTION);
		monitor.beginTask(INSTALL, 2);
		return super.installKF(stream, monitor);
	}

	@Override
	public boolean uninstall(Application application, IProgressMonitor monitor) throws ApplicationOperationException {
		checkPermission(application, ApplicationPermission.UNINSTALL_ACTION);
		monitor.beginTask(UNINSTALL, 2);
		return super.uninstallKF(application, monitor);
	}
}
