/*
 * Java
 *
 * Copyright 2015-2019 IS2T. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break IS2T warranties on the whole library.
 */
package ej.wadapps.multisandbox.service;

import ej.kf.Kernel;
import ej.service.loader.CompositeServiceLoader;
import ej.service.loader.FilePropertiesServiceLoader;
import ej.service.loader.SystemPropertiesServiceLoader;
import ej.wadapps.service.SharedServiceFactory;

/**
 * Defines the order of the service loading resolution:
 * <ol>
 * <li>the services defined by dependency injection locally in the application or kernel.</li>
 * <li>the services shared in the instance of the shared registry.</li>
 * <li>the services defined by dependency injection globally in the system properties.</li>
 * </ol>
 */
public class ServiceLoaderKF extends CompositeServiceLoader {

	private static final String PROPERTIES_PACKAGE = "/properties/"; //$NON-NLS-1$
	private static final String SERVICES_LIST = ".services"; //$NON-NLS-1$

	/**
	 * Creates the service loader.
	 */
	public ServiceLoaderKF() {
		String name = Kernel.getContextOwner().getName();
		addServiceLoader(new FilePropertiesServiceLoader(PROPERTIES_PACKAGE + name + SERVICES_LIST));
		addServiceLoader(SharedServiceFactory.getSharedServiceRegistry());
		addServiceLoader(new SystemPropertiesServiceLoader());
	}
}
