/*
 * Java
 *
 * Copyright 2017-2019 IS2T. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break IS2T warranties on the whole library.
 */
package ej.wadapps.property;

import ej.service.loader.SystemPropertiesServiceLoader;

/**
 * The factory that retrieves the unique instance of the {@link SharedPropertyRegistry} sets by the system.
 */
public class SharedPropertyFactory {

	private static final SharedPropertyRegistry SHARED_PROPERTY_REGISTRY = getSharedPropertyRegistryInstance();

	private SharedPropertyFactory() {
	}

	private static SharedPropertyRegistry getSharedPropertyRegistryInstance() {
		SharedPropertyRegistry sharedPropertyRegistry = new SystemPropertiesServiceLoader()
				.getService(SharedPropertyRegistry.class);
		if (sharedPropertyRegistry == null) {
			throw new IllegalArgumentException();
		}
		return sharedPropertyRegistry;
	}

	/**
	 * Gets the global {@link SharedPropertyRegistry}.
	 *
	 * @return the global {@link SharedPropertyRegistry}.
	 */
	public static SharedPropertyRegistry getSharedPropertyRegistry() {
		return SHARED_PROPERTY_REGISTRY;
	}

}
