/*
 * Java
 *
 * Copyright 2015-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.widget.composed;

import ej.giml.annotation.Element;
import ej.giml.annotation.ElementAttribute;
import ej.giml.annotation.ElementConstructor;
import ej.giml.annotation.ElementRequiredAttribute;
import ej.widget.basic.Label;
import ej.widget.basic.drawing.SwitchBox;
import ej.widget.toggle.ToggleModel;

/**
 * A facility to use a switch that displays a text.
 * <p>
 * It is simply a toggle composite that contains a switch box and a label, based on a toggle model.
 *
 * @see Label
 * @see SwitchBox
 * @see ToggleModel
 */
@Element
public class Switch extends Toggle {

	/**
	 * Creates a switch with the text to display. The text cannot be <code>null</code>.
	 *
	 * @param text
	 *            the text to display.
	 * @throws NullPointerException
	 *             if the text is <code>null</code>.
	 */
	public Switch(String text) {
		super(new SwitchBox(), text);
	}

	/**
	 * Creates a switch with the text to display and its group. The text cannot be <code>null</code>.
	 *
	 * @param text
	 *            the text to display.
	 * @param group
	 *            the name of the toggle group.
	 * @throws NullPointerException
	 *             if the text is <code>null</code>.
	 */
	@ElementConstructor
	public Switch(@ElementRequiredAttribute String text, @ElementAttribute(defaultValue = "null") String group) {
		super(new ToggleModel(), new SwitchBox(), text, group);
	}

}
