/*
 * Java
 *
 * Copyright 2015-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.widget.navigation.navigator;

import ej.widget.navigation.Navigator;
import ej.widget.navigation.page.ClassNameURLResolver;
import ej.widget.navigation.page.Page;
import ej.widget.navigation.page.URLResolver;

/**
 * Manages the navigation between several pages.
 * 
 * @deprecated see {@link ej.widget.container.transition.TransitionContainer}.
 */
@Deprecated
public class SimpleNavigator extends Navigator {

	private final URLResolver urlResolver;

	/**
	 * Creates a simple navigation with a class name URL resolver.
	 *
	 * @see ClassNameURLResolver
	 */
	public SimpleNavigator() {
		this.urlResolver = new ClassNameURLResolver();
	}

	/**
	 * Creates a transition desktop.
	 *
	 * @param urlResolver
	 *            the URL resolver.
	 */
	public SimpleNavigator(URLResolver urlResolver) {
		this.urlResolver = urlResolver;
	}

	/**
	 * Shows a new page.
	 *
	 * @param url
	 *            the URL of the page to show.
	 * @param forward
	 *            <code>true</code> if going to a new page, <code>false</code> if going back in the stack of pages.
	 * @see URLResolver#resolve(String)
	 * @see #show(Page, boolean)
	 */
	public void show(String url, boolean forward) {
		Page page = this.urlResolver.resolve(url);
		show(page, forward);
	}

	@Override
	public void show(Page page, boolean forward) {
		super.show(page, forward);
	}

	/**
	 * Reloads the current page.
	 * <p>
	 * A new page with the same URL is created and replace the current one.
	 */
	public void reload() {
		String url = getCurrentPage().getCurrentURL();
		Page page = this.urlResolver.resolve(url);
		// Copy show() method to avoid possible animation.
		updateCurrentPage(page);
		setChildBounds(page);
		repaint();
	}

}
