/*
 * Copyright (c) 2014 IBM Corp.
 * Copyright 2016-2021 MicroEJ Corp. This file has been modified by MicroEJ Corp.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * and Eclipse Distribution License v1.0 which accompany this distribution.
 *
 * The Eclipse Public License is available at
 *    http://www.eclipse.org/legal/epl-v10.html
 * and the Eclipse Distribution License is available at
 *   http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * Contributions:
 *   Ian Craggs - MQTT 3.1.1 support
 */

package org.eclipse.paho.client.mqttv3;

import org.eclipse.paho.client.mqttv3.internal.Token;
import org.eclipse.paho.client.mqttv3.internal.wire.MqttWireMessage;

import ej.annotation.Nullable;

/**
 * Provides a mechanism for tracking the completion of an asynchronous action.
 * <p>
 * A token that implements the ImqttToken interface is returned from all non-blocking method with the exception of
 * publish.
 * </p>
 *
 * @see IMqttToken
 */

public class MqttToken implements IMqttToken {
	/**
	 * A reference to the the class that provides most of the implementation of the MqttToken. MQTT application programs
	 * must not use the internal class.
	 */
	@Nullable
	public Token internalTok = null;

	public MqttToken() {
	}

	public MqttToken(String logContext) {
		this.internalTok = new Token(logContext);
	}

	@Override
	@Nullable
	public MqttException getException() {
		return this.internalTok.getException();
	}

	@Override
	public boolean isComplete() {
		return this.internalTok.isComplete();
	}

	@Override
	public void setActionCallback(IMqttActionListener listener) {
		this.internalTok.setActionCallback(listener);

	}

	@Override
	@Nullable
	public IMqttActionListener getActionCallback() {
		return this.internalTok.getActionCallback();
	}

	@Override
	public void waitForCompletion() throws MqttException {
		this.internalTok.waitForCompletion(-1);
	}

	@Override
	public void waitForCompletion(long timeout) throws MqttException {
		this.internalTok.waitForCompletion(timeout);
	}

	@Override
	@Nullable
	public IMqttAsyncClient getClient() {
		return this.internalTok.getClient();
	}

	@Override
	@Nullable
	public String[] getTopics() {
		return this.internalTok.getTopics();
	}

	@Override
	@Nullable
	public Object getUserContext() {
		return this.internalTok.getUserContext();
	}

	@Override
	public void setUserContext(Object userContext) {
		this.internalTok.setUserContext(userContext);
	}

	@Override
	public int getMessageId() {
		return this.internalTok.getMessageID();
	}

	@Override
	public int[] getGrantedQos() {
		return this.internalTok.getGrantedQos();
	}

	@Override
	public boolean getSessionPresent() {
		return this.internalTok.getSessionPresent();
	}

	@Override
	@Nullable
	public MqttWireMessage getResponse() {
		return this.internalTok.getResponse();
	}
}
