/*
 * Copyright (c) 2009, 2014 IBM Corp.
 * Copyright 2015-2021 MicroEJ Corp. This file has been modified by MicroEJ Corp.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * and Eclipse Distribution License v1.0 which accompany this distribution.
 *
 * The Eclipse Public License is available at
 *    http://www.eclipse.org/legal/epl-v10.html
 * and the Eclipse Distribution License is available at
 *   http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * Contributors:
 *    Dave Locke - initial API and implementation and/or initial documentation
 */
package org.eclipse.paho.client.mqttv3.internal.security;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.List;

import org.eclipse.paho.client.mqttv3.internal.MicroEJSSLNetworkModuleFactory;

import com.microej.paho.client.mqttv3.CertificateProvider;

import ej.annotation.Nullable;

/**
 *
 */
public class ResourceCertificates implements CertificateProvider {
	private final List<String> certificates;

	/**
	 * @throws IOException
	 *
	 */
	public ResourceCertificates(@Nullable String certificatesList) throws IOException {
		this.certificates = new ArrayList<>();
		if (certificatesList != null) {
			try (InputStream listStream = MicroEJSSLNetworkModuleFactory.class.getResourceAsStream(certificatesList)) {
				if (listStream != null) {
					BufferedReader reader = new BufferedReader(new InputStreamReader(listStream));
					String certificate = reader.readLine();
					while (certificate != null) {
						this.certificates.add(certificate);
						certificate = reader.readLine();
					}
				}
			}
		}
	}

	@Override
	public int getSize() {
		return this.certificates.size();
	}

	@Override
	@Nullable
	public InputStream getCertificate(int index) {
		return ResourceCertificates.class.getResourceAsStream(this.certificates.get(index));
	}

	@Override
	public String getAlias(int index) {
		return this.certificates.get(index);
	}
}
